@@ -115,8 +115,8 @@ class Bucket(core.Construct):
         environment,
         environments_parameters,
         bucket_name,
-        bucket_is_public="False",
-        bucket_has_cdn="False",
+        bucket_is_public=None,
+        bucket_has_cdn=None,
         bucket_website_index_document=None,
         bucket_website_error_document=None,
         bucket_is_privately_accessed_from_vpc_over_http=False,
