@@ -102,6 +102,8 @@ class Microservice(core.Construct):
         will_use_efs (str): Wether or not should create a EFS
 
         will_use_cdn (str): Wether or not the Application Load Balancer should receive traffic only from Cloudflare CDN
+        
+        will_use_ldap (str): Wether or not the EC2 instance should be able to integrate with LDAP. This configuration set-up the LDAP client security group to the EC2
 
     """
 
@@ -293,15 +295,16 @@ class Microservice(core.Construct):
         if load_balancer_name is None:
             load_balancer_name = id
 
-        # Always 
+        # In case CDN is in use, create a new Security Group with access
+        # Only from Cloudflare and replace the provided Security Group with the newly 
+        # created one 
         if use_cdn:
-
             cdn_security_group = self.create_security_group(
                 self, 
                 "alb_sg_cdn", 
                 app_name, 
                 environment, 
-                app_name + "_alb_sg_cdn"
+                app_name + "_alb_sg_cdn",
                 )
 
             # Cloudflare doc https://support.cloudflare.com/hc/en-us/articles/360037983412-Configuring-an-Amazon-Web-Services-static-site-to-use-Cloudflare
@@ -338,14 +341,13 @@ class Microservice(core.Construct):
                 "2c0f:f248::/32",
                 "2a06:98c0::/29",
             ]
-
             for ip in cloudflare_ips_v6:
                 cdn_security_group.add_ingress_rule(                
                     peer=_ec2.Peer.ipv6(ip),
                     connection=self._tcp_connection_traffic_port,
                     description="Cloudflare ipv6",
                     )     
-
+                    
             security_group = cdn_security_group
 
         alb = _alb.ApplicationLoadBalancer(
@@ -357,6 +359,7 @@ class Microservice(core.Construct):
             idle_timeout=core.Duration.seconds(50),
             security_group=security_group,
         )
+        
         # Enable logging
         alb.log_access_logs(self._alb_logs_bucket, prefix=self._app_name)
 
@@ -505,6 +508,7 @@ class Microservice(core.Construct):
         client_id=None,
         client_secret=None,
         user_info_endpoint=None,
+        will_use_ldap=None,
         additional_variables: dict = None,
         **kwargs
     ):
@@ -538,9 +542,20 @@ class Microservice(core.Construct):
 
         has_upstream = not not upstream_security_group
         has_not_upstream = not has_upstream
-
+        use_cdn = (
+            will_use_cdn and isinstance(will_use_cdn, str) and will_use_cdn.lower() == "true"
+        )
+        not_use_cdn = not use_cdn
+        
         is_public_and_no_upstream = is_public and has_not_upstream
         is_public_and_has_upstream = is_public and has_upstream
+        is_public_and_no_upstream_and_no_cdn = is_public and has_not_upstream and not_use_cdn
+        is_private_and_is_https = is_private and is_https
+        is_public_has_no_upstream_and_is_https = (
+            has_not_upstream and is_public and is_https
+        )
+        is_public_has_upstream_and_is_https = has_upstream and is_public and is_https
+        is_public_has_no_upstream_and_is_https_and_no_cdn = is_public_has_no_upstream_and_is_https and not_use_cdn
 
         has_downstream = not not downstream_security_group
         has_not_downstream = not has_downstream
@@ -550,10 +565,7 @@ class Microservice(core.Construct):
         )
         is_not_ha = not is_ha
 
-        use_cdn = (
-            will_use_cdn and isinstance(will_use_cdn, str) and will_use_cdn.lower() == "true"
-        )
-        
+
         use_ebs = not not ebs_volume_size
         create_ebs = use_ebs and is_not_ha
 
@@ -563,12 +575,6 @@ class Microservice(core.Construct):
             and will_use_efs.lower() == "true"
         )
 
-        is_private_and_is_https = is_private and is_https
-
-        is_public_has_no_upstream_and_is_https = (
-            has_not_upstream and is_public and is_https
-        )
-        is_public_has_upstream_and_is_https = has_upstream and is_public and is_https
 
         self._environments_parameters = environments_parameters
         aws_account = self._environments_parameters["accounts"][environment.lower()]
@@ -605,6 +611,12 @@ class Microservice(core.Construct):
             alphanumericPattern, "", "".join([main_component_name, "AutoScalingGroup"])
         )
 
+        use_ldap = (
+            will_use_ldap and isinstance(will_use_ldap, str) and will_use_ldap.lower() == "true"
+        )
+
+        
+
         # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Validate input params
 
         if has_additional_variables and type(additional_variables) is not dict:
@@ -678,13 +690,17 @@ class Microservice(core.Construct):
         # Elastic Load Balancer Security Group
         # ~~~~~~~~~~~~~~~~
         self.alb_security_group = self.create_security_group(
-            self, "alb_sg", app_name, environment, app_name + '_' + main_component_name + "_alb_sg"
+            self, 
+            "alb_sg", 
+            app_name, 
+            environment, 
+            app_name + '_' + main_component_name + "_alb_sg"
         )
 
         if is_private:
             self.enable_fao_private_access(self.alb_security_group)
 
-        if is_public_and_no_upstream:
+        if is_public_and_no_upstream_and_no_cdn:
             self.alb_security_group.add_ingress_rule(
                 peer=_ec2.Peer.any_ipv4(),
                 connection=self._tcp_connection_traffic_port,
@@ -711,7 +727,7 @@ class Microservice(core.Construct):
                 description="FAO HQ Clients",
             )
         # Used when HTTPS is forced. These rules enable the redirect from HTTP -> HTTPS
-        if is_public_has_no_upstream_and_is_https:
+        if is_public_has_no_upstream_and_is_https_and_no_cdn:
             self.alb_security_group.add_ingress_rule(
                 peer=_ec2.Peer.any_ipv4(),
                 connection=_ec2.Port.tcp(80),
@@ -745,6 +761,7 @@ class Microservice(core.Construct):
             self.alb.add_listener(
                 "is_not_https",
                 port=int(traffic_port),
+                open=False, 
                 protocol=_alb.ApplicationProtocol.HTTP,
                 default_target_groups=[self._tg],
             )
@@ -754,6 +771,7 @@ class Microservice(core.Construct):
             self.alb.add_listener(
                 "redirect_to_https",
                 port=80,
+                open=False, 
                 protocol=_alb.ApplicationProtocol.HTTP,
                 default_action=_alb.ListenerAction.redirect(
                     host="#{host}",
@@ -777,6 +795,7 @@ class Microservice(core.Construct):
                     protocol=_alb.ApplicationProtocol.HTTPS,
                     certificates=[certificate],
                     default_target_groups=[self._tg],
+                    open=False, 
                     ssl_policy=_alb.SslPolicy.FORWARD_SECRECY_TLS12_RES
                 )
 
@@ -801,6 +820,7 @@ class Microservice(core.Construct):
                 self.alb.add_listener(
                     "is_https",
                     port=int(traffic_port),
+                    open=False, 
                     protocol=_alb.ApplicationProtocol.HTTPS,
                     certificates=[certificate],
                     default_action=oidc_listener_action,
@@ -1185,7 +1205,15 @@ class Microservice(core.Construct):
                 mutable=False,
             )
             self._asg.add_security_group(smtp_access_security_group)
-            
+
+        if use_ldap:
+            ldap_access_security_group = _ec2.SecurityGroup.from_security_group_id(
+                self,
+                "ldap_access_security_group",
+                aws_account["ldap_access_security_group"],
+                mutable=False,
+            )
+            self._asg.add_security_group(ldap_access_security_group)      
 
         # Scaling policies
         self._asg.scale_on_cpu_utilization(
