@@ -114,7 +114,7 @@ class ServiceUserForIAC(core.Construct):
                         "iam:PassRole",
                         "iam:DeleteAccessKey",
                         "rds:DescribeEngineDefaultParameters",
-                        "elasticfilesystem:DeleteMountTarget",
+                        "elasticfilesystem:*MountTarget",
                         "elasticfilesystem:DescribeFileSystems",
                         "ec2:*Volume*"
                     ],
@@ -240,6 +240,27 @@ class ServiceUserForIAC(core.Construct):
                     conditions={
                         "ForAnyValue:StringLikeIfExists": {
                             "aws:RequestTag/ApplicationName": app_name,
+                        }
+                    },
+                ),
+                _iam.PolicyStatement(
+                    actions=[
+                        "cloudformation:*",
+                        "s3:*",
+                        "ec2:*",
+                        "elasticloadbalancingv2:*",
+                        "elasticloadbalancing:*",
+                        "rds:*",
+                        "secretsmanager:*",
+                        "autoscaling:*",
+                        "lambda:*",
+                        "logs:*",
+                        "iam:*",
+                        "elasticfilesystem:*",
+                    ],
+                    resources=["*"],
+                    conditions={
+                        "ForAnyValue:StringLikeIfExists": {
                              "ec2:ResourceTag/ApplicationName": app_name
                         }
                     },
